/*
   htmlget.c - htmlget: A html ripper
   Copyright (c) 1999  Martin Hinner <martin@tdp.cz>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <getopt.h>

#include "html.h"

int grab_title;
int grab_urls;
int grab_imageurls;

int is_title;

char *help_text = "Usage: %s [OPTION] [FILES]\n\n"
                  "-u         Print urls from HTML file\n"
                  "-i         Print image urls from HTML file\n"
                  "-t         Print title\n"
                  "\n"
                  "Report bugs to martin@tdp.cz\n";

int processchar(char c)
{
 if (is_title)
  putchar(c);
}

int processtag(char *tag)
{
	char **argv;
	int argc,x;
        char *url;

	argv = (char **)malloc(0x100*sizeof(char *));

	argc = parsehtmltag(tag,argv,0x100);

        if (grab_urls) 
 	 if (!strcasecmp(argv[0],"A")) {
           url = htmlgetparam(argc,argv,"href");
           if (url)
            printf("%s\n",url);
          }
        if (grab_imageurls) 
         if (!strcasecmp(argv[0],"IMG")) {
           url = htmlgetparam(argc,argv,"src");
           if (url)
            printf("%s\n",url);
          }
        if (grab_title) {
         if (!strcasecmp(argv[0],"TITLE")) is_title = 1;
         if (!strcasecmp(argv[0],"/TITLE")) is_title = 0;
        }

	return 0;
}

void usage(char *progname)
{
	printf("Usage: %s htmlfile\n",progname);
	exit(-1);
}

int main(int argc,char **argv)
{
  int handle;
  int errors;
  char ch;
  char *myname;

  myname = strrchr(argv[0],'/');
  myname = myname?myname+1:argv[0];

  if (!strcmp(myname,"htmlgettitle"))
   grab_title = 1; else
  if (!strcmp(myname,"htmlgeturls"))
   grab_urls = 1;

  while ((ch = getopt (argc, argv, "tuih")) != EOF)
    switch (ch)
     {
      case 't':
        grab_title = 1;
        break;
      case 'u':
        grab_urls = 1;
        break;
      case 'i':
        grab_imageurls = 1;
        break;
      case 'h':
        printf(help_text,argv[0]);
        return 0;
     }

  if ( !(grab_urls||grab_title||grab_imageurls) )
   {
    fprintf(stderr,"Try '%s -h' for more information\n",argv[0]);
    grab_urls = 1;
   }

  argc -= optind;
  argv += optind;

  errors = 0;
  is_title = 0;

  if (argc)
   {
    while (argc--) {
      handle = open(*argv,O_RDONLY);
      if (handle==-1) {
        perror(*argv);
        errors++;
       }else {
        parsehtml(handle,processtag,processchar);
        close(handle);
       }
      argv++;
     }
   }else
   {
     parsehtml(0,processtag,processchar);
   }

 return errors?1:0;
}
